ChangeLog
=========

v0.2.3
------

* Added manual, accessible from help menu
* Improved bundling of code on Windows to enable the creation of an installer

v0.2.2
------

* adding more readable log messages for changing state, new files for MANIFEST.in, and proper paths for windows pyqt file generation
* adding \*.ui files to MANIFEST.in
* checking for bluetooth IOError to deal with a bug on windows
